@@ -7,14 +7,14 @@ use Resource::Pack::jQuery;
 use File::Temp qw( tempdir );
 use Path::Class qw( file dir );
 use Moose::Util::TypeConstraints qw( enum );
-use File::HomeDir;
+use File::Glob qw( bsd_glob );
 
 with 'Dist::Zilla::Role::FileGatherer';
 
 use namespace::autoclean;
 
 # ABSTRACT: Include jQuery in your distribution
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
 has version => (
@@ -71,7 +71,8 @@ has _cache_dir => (
     }
     else
     {
-      my $dir = dir( File::HomeDir->my_dist_data("Dist-Zilla-Plugin-jQuery", { create => 1 }) );
+      my $dir = dir( bsd_glob '~/.local/share/Perl/dist/Dist-Zilla-Plugin-jQuery' );
+      $dir->mkpath(0,0700);
       $dir = $dir->subdir( $self->version, $self->minified );
       unless(-d $dir)
       {
@@ -154,7 +155,7 @@ Dist::Zilla::Plugin::jQuery - Include jQuery in your distribution
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
